#include <QtGui/QApplication>
#include "mainwindow.h"
#include "pwqdialog.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    MainWindow w;
    //QObject::connect((QObject*)w.close(), SIGNAL(quit()), &a, SLOT(quit()));
#if defined(Q_WS_S60)
    w.showMaximized();
    return a.exec();
#else
    PWQDialog pwdDialog;
    if (pwdDialog.exec()==PWQDialog::Accepted)
    {
        w.show();
        return a.exec();
    }
    else a.quit();
#endif

}
